# Changelog

## 1.0
* Initial Release.

## 1.0.1
* Updating the build process for travis-ci.
* Ensured it could push to PyPi repo.
* Adding pytest unit tests.

## 1.0.2
* Add helper method to get a proper rating object.
  * Added tests for this method.
  
## 1.0.3
* Updating the setup and dependencies.

## 1.0.4
* Fixed missing files in pypi.